﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Citrix.XaAdminMobile.Model
{
    /// <summary>
    /// The event arguments for the <see cref="IServersModel.ServersChanged"/> event.
    /// </summary>
    internal class ServersChangedArgs : EventArgs
    {
        /// <summary>
        /// Ctor.
        /// </summary>
        /// <param name="addedServers">The set of added servers, maybe null.</param>
        /// <param name="removedServers">The of removed servers, maybe null.</param>
        internal ServersChangedArgs(List<IServerModel> addedServers, List<IServerModel> removedServers)
        {
            if (null == addedServers)
            {
                this.AddedServers = new List<IServerModel>();
            }
            else
            {
                this.AddedServers = addedServers;
            }
            if (null == removedServers)
            {
                this.RemovedServers = new List<IServerModel>();
            }
            else
            {
                this.RemovedServers = removedServers;
            }
        }

        /// <summary>
        /// The added servers. Will never be null.
        /// </summary>
        public List<IServerModel> AddedServers
        {
            get;
            private set;
        }

        /// <summary>
        /// The removed servers. Will never be null.
        /// </summary>
        public List<IServerModel> RemovedServers
        {
            get;
            private set;
        }
    }
}
