﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using Citrix.Cmp;

namespace Citrix.XaAdminMobile.Model.Test
{
    /// <summary>
    /// Holds a collection of known servers in a XenApp farm. This version provides static test
    /// data.
    /// </summary>
    internal class TestServersModel : IServersModel
    {
        /// <summary>
        /// Fired when the set of servers changes.
        /// </summary>
        public event EventHandler<ServersChangedArgs> ServersChanged;

        /// <summary>
        /// The internal store of servers.
        /// </summary>
        private List<IServerModel> servers = null;

        /// <summary>
        /// Initialisation ctor.
        /// </summary>
        internal TestServersModel()
        {
            this.servers = new List<IServerModel>();
            this.servers.Add(new TestServerModel
            {
                Name = "XENAPPTEST1",
                SessionCount = 6,
                Load = 2689
            });
            this.servers.Add(new TestServerModel
            {
                Name = "XENAPPTEST2",
                SessionCount = 4,
                Load = 1349
            });
        }

        /// <summary>
        /// Whether or not there is an active query to reload the server state.
        /// </summary>
        public bool IsLoading
        {
            get
            {
                return false;
            }
        }

        /// <summary>
        /// Returns the last error (if any) when loading server state. Null means the last load
        /// was successful.
        /// </summary>
        public string LastLoadError
        {
            get { return null; }
        }

        /// <summary>
        /// Reloads the server state for the farm.
        /// </summary>
        public void Refresh()
        {
            // Not supported for test data.
        }

        /// <summary>
        /// Returns the last loaded set of server state.
        /// </summary>
        public List<IServerModel> Servers
        {
            get { return this.servers; }
        }

        #region INotifyPropertyChanged Members

        /// <summary>
        /// Fired whenever a public property changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Fires the property change event. Maybe called from any thread - we always fire the
        /// event on the main UI thread.
        /// </summary>
        /// <param name="propertyName">The name of the property that changed.</param>
        private void OnPropertyChanged(string propertyName)
        {
            NotifyHelper.VerifyProperty(propertyName, this);
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged.Raise(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion // INotifyPropertyChanged Members
    }
}
