﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using Citrix.Cmp;

namespace Citrix.XaAdminMobile.Model.Test
{
    class TestSessionsModel : ISessionsModel
    {
        public event EventHandler<SessionsChangedArgs> SessionsChanged;

        private List<ISessionModel> sessions = new List<ISessionModel>();

        /// <summary>
        /// Ctor - creates a bunch of test data.
        /// </summary>
        public TestSessionsModel()
        {
            for (int i = 0; i < 1; ++i)
            {
                AddFakeSessions();
            }

            // Shutup compiler warning about not using the event.
            SessionsChanged.Raise(this, new SessionsChangedArgs(null, null));
        }

        /// <summary>
        /// Creates a set of test sessions.
        /// </summary>
        private void AddFakeSessions()
        {
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\danielr",
                BrowserName = "GoldenGate",
                ServerName = "XENAPPTEST1",
                SessionId = 4,
                State = XenApp.Commands.SessionConnectionState.Active
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\danielr",
                BrowserName = "Excel",
                ServerName = "XENAPPTEST2",
                SessionId = 13
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\rachelm",
                BrowserName = "Outlook 2010",
                ServerName = "XENAPPTEST1",
                SessionId = 8
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\charlesw",
                BrowserName = "SAP Portal",
                ServerName = "XENAPPTEST2",
                SessionId = 22
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\charlesw",
                BrowserName = "Word 2010",
                ServerName = "XENAPPTEST1",
                SessionId = 14
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\martinm",
                BrowserName = "Vantive ERM",
                ServerName = "XENAPPTEST1",
                SessionId = 21,
                State = XenApp.Commands.SessionConnectionState.Active
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\traceyk",
                BrowserName = "Outlook 2010",
                ServerName = "XENAPPTEST2",
                SessionId = 24
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\jamiep",
                BrowserName = "GoldenGate",
                ServerName = "XENAPPTEST1",
                SessionId = 34,
                State = XenApp.Commands.SessionConnectionState.Active
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\jamiep",
                BrowserName = "Excel 2010",
                ServerName = "XENAPPTEST2",
                SessionId = 30
            });
            this.sessions.Add(new TestSessionModel
            {
                AccountName = "TEST\\phillipan",
                BrowserName = "Outlook 2010",
                ServerName = "XENAPPTEST1",
                SessionId = 38
            });
        }

        /// <summary>
        /// Whether or not the model is currently loading new session state.
        /// </summary>
        public bool IsLoading
        {
            get
            {
                return false;
            }
        }

        /// <summary>
        /// Returns the last error (if any) when loading server state. Null means the last load
        /// was successful.
        /// </summary>
        public string LastLoadError
        {
            get { return null; }
        }

        public void Refresh()
        {
            // Do nothing
        }

        public void Reset(List<ISessionModel> sessions)
        {
            // Do nothing
        }

        public List<ISessionModel> Sessions
        {
            get { return this.sessions; }
        }

        #region INotifyPropertyChanged Members

        /// <summary>
        /// Fired whenever a public property changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Fires the property change event. Maybe called from any thread - we always fire the
        /// event on the main UI thread.
        /// </summary>
        /// <param name="propertyName">The name of the property that changed.</param>
        private void OnPropertyChanged(string propertyName)
        {
            NotifyHelper.VerifyProperty(propertyName, this);
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged.Raise(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion // INotifyPropertyChanged Members
    }
}
