﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Citrix.XaAdminMobile.ViewModel
{
    /// <summary>
    /// The view-model for BlankPageView. Used to display a special "blank" page in the right
    /// hand column on the tablet layout.
    /// </summary>
    internal class BlankPageViewModel : IPage
    {
        /// <summary>
        /// A ref back to the root v-m object.
        /// </summary>
        private ViewModelManager vmRoot;

        /// <summary>
        /// Ctor.
        /// </summary>
        /// <param name="vmManager">The root v-m object.</param>
        /// <exception cref="ArgumentNullException">Thrown if any arg is null.</exception>
        internal BlankPageViewModel(ViewModelManager vmManager)
        {
            if (null == vmManager)
            {
                throw new ArgumentNullException("vmManager");
            }

            this.vmRoot = vmManager;
        }

        /// <summary>
        /// The message to display on the page.
        /// </summary>
        public string Message
        {
            get;
            set;
        }

        /// <summary>
        /// IPage.NotifyActiveChanged - not used.
        /// </summary>
        /// <param name="isActive"></param>
        public void NotifyActiveChanged(bool isActive)
        {
        }

        /// <summary>
        /// IPage.NotifyBackButtonPressed - not used.
        /// </summary>
        public void NotifyBackButtonPressed()
        {
        }

        /// <summary>
        /// IPage.VmManager, returns the root v-m object.
        /// </summary>
        public ViewModelManager VmManager
        {
            get { return this.vmRoot; }
        }
    }
}
